==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_theme.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_theme.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("TPVLAN_1", "You are looking at a preview of the <b>'".PREVIEWTHEMENAME."'</b> theme. It has not been set as the main theme for your site, it has been activated to provide a preview of how the theme looks.<br />To set this theme as your site theme, <a href='".e_ADMIN."theme.php'>return to your theme manager</a> and select 'Set As Site Theme'.<br />To preview more themes please <a href='".e_ADMIN."theme.php'>click here</a>");
define("TPVLAN_2", "Theme Preview");
define("TPVLAN_3", "Main site theme set to");
define("TPVLAN_4", "Author");
define("TPVLAN_5", "Website");
define("TPVLAN_6", "Release date");
define("TPVLAN_7", "Information");
define("TPVLAN_8", "Options");
define("TPVLAN_9", "Preview Theme");
define("TPVLAN_10", "Set As Site Theme");
define("TPVLAN_11", "Version");
define("TPVLAN_12", "No preview available");

define("TPVLAN_13", "Upload theme (.zip or .tar.gz format)");
define("TPVLAN_14", "Upload Theme");
define("TPVLAN_15", "The file could not be uploaded as the ".e_THEME." folder does not have the correct permissions - please CHMOD to 777 and re-upload the file.");
define("TPVLAN_16", "Admin Message");
define("TPVLAN_17", "That file does not appear to be a valid .zip or .tar archive.");
define("TPVLAN_18", "An error has occurred, unable to un-archive the file");
define("TPVLAN_19", "Your theme has been uploaded and unzipped, please scroll down to see your theme in the list.");
define("TPVLAN_20", "Auto theme upload and extraction is disabled as your themes folder does not have the correct permissions - please CHMOD your e107_themes folder to 777.");

define("TPVLAN_21", "This is the currently selected site theme");

define("TPVLAN_22", "This theme has multiple stylesheets");
define("TPVLAN_23", "default stylesheet");
define("TPVLAN_24", "no information");
define("TPVLAN_25", "To choose which stylesheet to use, please go to <a href='".e_ADMIN."prefs.php'>preferences</a> and click on 'Theme'.");

define("TPVLAN_26", "Theme Manager");
define("TPVLAN_27", "Please select stylesheet to use");
define("TPVLAN_28", "on");
define("TPVLAN_29", "off");
define("TPVLAN_30", "Preload Theme Images:");

define("TPVLAN_31", "This is the currently selected admin theme");
define("TPVLAN_32", "Set As Admin Theme");

define("TPVLAN_33", "Current Site Theme");
define("TPVLAN_34", "Current Admin Theme");
define("TPVLAN_35", "Save options");
define("TPVLAN_36", "Admin Message");
define("TPVLAN_37", "Theme options saved");
define("TPVLAN_38", "Upload Theme");
define("TPVLAN_39", "Available Themes");
define("TPVLAN_40", "Admin theme set to");

define("TPVLAN_41", "Please select admin layout style to use");
define("TPVLAN_42", "Save admin options");
define("TPVLAN_43", "Admin options saved");

define("TPVLAN_46", "PCLZIP extract error:");
define("TPVLAN_47", "PCLTAR extract error: ");
define("TPVLAN_48", "code:");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_theme.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_theme.php $
|     $Revision: 11678 $
|     $Id: lan_theme.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/

define("TPVLAN_1", "You are looking at a preview of the <b>'".PREVIEWTHEMENAME."'</b> theme. It has not been set as the main theme for your site, it has been activated to provide a preview of how the theme looks.<br />To set this theme as your site theme, <a href='".e_ADMIN."theme.php'>return to your theme manager</a> and select 'Set As Site Theme'.<br />To preview more themes please <a href='".e_ADMIN."theme.php'>click here</a>");
define("TPVLAN_2", "Theme Preview");
define("TPVLAN_3", "Main site theme set to");
define("TPVLAN_4", "Author");
define("TPVLAN_5", "Website");
define("TPVLAN_6", "Release date");
define("TPVLAN_7", "Information");
define("TPVLAN_8", "Options");
define("TPVLAN_9", "Preview Theme");
define("TPVLAN_10", "Set As Site Theme");
define("TPVLAN_11", "Version");
define("TPVLAN_12", "No preview available");

define("TPVLAN_13", "Upload theme (.zip or .tar.gz format)");
define("TPVLAN_14", "Upload Theme");
define("TPVLAN_15", "The file could not be uploaded as the ".e_THEME." folder does not have the correct permissions - please CHMOD to 777 and re-upload the file.");
define("TPVLAN_16", "Admin Message");
define("TPVLAN_17", "That file does not appear to be a valid .zip or .tar archive.");
define("TPVLAN_18", "An error has occurred, unable to un-archive the file");
define("TPVLAN_19", "Your theme has been uploaded and unzipped, please scroll down to see your theme in the list.");
define("TPVLAN_20", "Auto theme upload and extraction is disabled as your themes folder does not have the correct permissions - please CHMOD your e107_themes folder to 777.");

define("TPVLAN_21", "This is the currently selected site theme");

define("TPVLAN_22", "This theme has multiple stylesheets");
define("TPVLAN_23", "default stylesheet");
define("TPVLAN_24", "no information");
//define("TPVLAN_25", "To choose which stylesheet to use, please go to <a href='".e_ADMIN_ABS."theme.php'>Theme Manager</a> and click on 'Theme'.");

define("TPVLAN_26", "Theme Manager");
define("TPVLAN_27", "Please select stylesheet to use");
define("TPVLAN_28", "on");
define("TPVLAN_29", "off");
define("TPVLAN_30", "Preload Theme Images:");

define("TPVLAN_31", "This is the currently selected admin theme");
define("TPVLAN_32", "Set As Admin Theme");

define("TPVLAN_33", "Current Site Theme");
define("TPVLAN_34", "Current Admin Theme");
define("TPVLAN_35", "Save options");
define("TPVLAN_36", "Admin Message");
define("TPVLAN_37", "Theme options saved");
define("TPVLAN_38", "Upload Theme");
define("TPVLAN_39", "Available Themes");
define("TPVLAN_40", "Admin theme set to");

define("TPVLAN_41", "Please select admin layout style to use");
define("TPVLAN_42", "Save admin options");
define("TPVLAN_43", "Admin options saved");

define("TPVLAN_46", "PCLZIP extract error:");
define("TPVLAN_47", "PCLTAR extract error: ");
define("TPVLAN_48", "code:");

?>
